@@ -24,7 +24,7 @@
 # @author
 #
 # \seealso{
-#   To check if it is a directory see @seemethod "isDirectory".
+#   To check if it is a directory see @see "isDirectory".
 #   Internally @see "base::file.info" is used.
 # }
 #
@@ -32,13 +32,40 @@
 # @keyword programming
 #*/########################################################################### 
 setMethodS3("isFile", "default", function(pathname, ...) {
+  if (length(pathname) == 0)
+    return(FALSE);
+
   pathname <- as.character(pathname);
+
   isdir <- file.info(pathname)$isdir;
-  identical(isdir, FALSE);
+  if (identical(isdir, FALSE))
+    return(TRUE);
+
+  if (is.na(isdir)) {
+    if (!isAbsolutePath(pathname))
+      return(FALSE);
+
+    # Try the relative pathname
+    relPathname <- getRelativePath(pathname);
+
+    # Avoid infinite recursive loops; check if succeeded in getting a 
+    # relative pathname? 
+    if (!identical(relPathname, pathname)) {
+      return(isFile(relPathname));
+    } else {
+      # At this point, we can only return FALSE.
+      return(FALSE);
+    }
+  }
+
+  return(FALSE);
 })
 
 ###########################################################################
 # HISTORY: 
+# 2005-11-29
+# o BUG FIX: Added protection against infinite loops where relative path 
+#   is the same as the absolute path.
 # 2005-05-29
 # o Created by copying code in the File class of the R.io package.
 ###########################################################################
